// src/mendertooltip.js
import React, { useEffect, useState } from "react";
import { Help as HelpIcon } from "@mui/icons-material";
import { ClickAwayListener, Tooltip } from "@mui/material";
import { makeStyles, withStyles } from "tss-react/mui";
import { READ_STATES, TIMEOUTS } from "@northern.tech/store/constants";
import { useDebounce } from "@northern.tech/utils/debouncehook";
import { toggle } from "@northern.tech/utils/helpers";
import { jsx, jsxs } from "react/jsx-runtime";
var useStyles = makeStyles()((theme) => ({
  icon: {
    "&.read": {
      color: theme.palette.text.disabled
    }
  },
  iconAura: {
    position: "absolute",
    top: -5,
    bottom: 0,
    left: -5,
    right: -5,
    border: `1px dashed ${theme.palette.primary.main}`,
    borderRadius: "50%",
    "&.read": {
      borderColor: theme.palette.text.disabled
    }
  }
}));
var MenderTooltip = withStyles(Tooltip, ({ palette, shadows, spacing }) => ({
  arrow: {
    color: palette.background.paper
  },
  tooltip: {
    backgroundColor: palette.background.paper,
    boxShadow: shadows[1],
    color: palette.text.primary,
    padding: spacing(2),
    fontSize: "small",
    maxWidth: 600,
    info: {
      maxWidth: 300,
      color: palette.text.hint,
      backgroundColor: palette.grey[500]
    }
  }
}));
var MenderTooltipClickable = ({
  children,
  onboarding,
  startOpen = false,
  visibility = startOpen,
  onOpenChange,
  tooltipComponent = MenderTooltip,
  ...remainingProps
}) => {
  const [open, setOpen] = useState(startOpen || false);
  useEffect(() => {
    setOpen(visibility);
  }, [visibility]);
  useEffect(() => {
    if (!onOpenChange) {
      return;
    }
    onOpenChange(open);
  }, [open, onOpenChange]);
  const toggleVisibility = () => setOpen(toggle);
  const hide = () => setOpen(false);
  const Component = onboarding ? OnboardingTooltip : tooltipComponent;
  const extraProps = onboarding ? {
    PopperProps: {
      disablePortal: true,
      popperOptions: {
        strategy: "fixed",
        modifiers: [
          { name: "flip", enabled: false },
          { name: "preventOverflow", enabled: true, options: { boundary: window, altBoundary: false } }
        ]
      }
    }
  } : {};
  return /* @__PURE__ */ jsx(ClickAwayListener, { onClickAway: hide, children: /* @__PURE__ */ jsx(
    Component,
    {
      arrow: !onboarding,
      open,
      disableFocusListener: true,
      disableHoverListener: true,
      disableTouchListener: true,
      onOpen: () => setOpen(true),
      ...extraProps,
      ...remainingProps,
      children: /* @__PURE__ */ jsx("div", { onClick: toggleVisibility, children })
    }
  ) });
};
var iconWidth = 30;
var OnboardingTooltip = withStyles(Tooltip, (theme) => ({
  arrow: {
    color: theme.palette.primary.main
  },
  tooltip: {
    backgroundColor: theme.palette.primary.main,
    boxShadow: theme.shadows[1],
    color: theme.palette.grey[500],
    fontSize: 14,
    maxWidth: 350,
    padding: "12px 18px",
    width: 350,
    "& a": {
      color: theme.palette.grey[500]
    },
    "&.MuiTooltip-tooltipPlacementTop": { marginLeft: iconWidth, marginBottom: 0, marginTop: `calc(${iconWidth} + ${theme.spacing(1.5)})` },
    "&.MuiTooltip-tooltipPlacementRight": { marginTop: iconWidth / 2 },
    "&.MuiTooltip-tooltipPlacementBottom": { marginLeft: iconWidth },
    "&.MuiTooltip-tooltipPlacementLeft": { marginTop: iconWidth / 2 }
  },
  popper: {
    opacity: 0.9
  }
}));
var mendertooltip_default = MenderTooltip;
var tooltipStateStyleMap = {
  [READ_STATES.read]: "read muted",
  default: ""
};
var TooltipWrapper = ({ content, onClose, onReadAll }) => /* @__PURE__ */ jsxs("div", { children: [
  content,
  /* @__PURE__ */ jsxs("div", { className: "flexbox space-between margin-top-small", children: [
    /* @__PURE__ */ jsx("span", { className: "link", onClick: onReadAll, children: "Mark all help tips as read" }),
    /* @__PURE__ */ jsx("span", { className: "link", onClick: onClose, children: "Close" })
  ] })
] });
var HelpTooltip = ({ icon = void 0, id, contentProps = {}, tooltip, device, setAllTooltipsReadState, setTooltipReadState, ...props }) => {
  const [isOpen, setIsOpen] = useState(false);
  const debouncedIsOpen = useDebounce(isOpen, TIMEOUTS.threeSeconds);
  const { classes } = useStyles();
  const { Component, SpecialComponent, isRelevant, readState } = tooltip;
  useEffect(() => {
    if (!debouncedIsOpen) {
      return;
    }
    setTooltipReadState({ id, persist: true, readState: READ_STATES.read });
  }, [debouncedIsOpen, id, setTooltipReadState]);
  const onReadAllClick = () => setAllTooltipsReadState(READ_STATES.read);
  const title = SpecialComponent ? /* @__PURE__ */ jsx(SpecialComponent, { device, ...contentProps }) : /* @__PURE__ */ jsx(TooltipWrapper, { content: /* @__PURE__ */ jsx(Component, { device, ...contentProps }), onClose: () => setIsOpen(false), onReadAll: onReadAllClick });
  if (!isRelevant({ device, ...contentProps })) {
    return null;
  }
  const className = tooltipStateStyleMap[readState] ?? tooltipStateStyleMap.default;
  return /* @__PURE__ */ jsx(MenderTooltipClickable, { className: isOpen ? "muted" : "", title, visibility: isOpen, onOpenChange: setIsOpen, ...props, children: /* @__PURE__ */ jsxs("div", { className: "relative", children: [
    icon || /* @__PURE__ */ jsx(HelpIcon, { className: `${classes.icon} ${className}`, color: "primary" }),
    /* @__PURE__ */ jsx("div", { className: `${classes.iconAura} ${className}` })
  ] }) });
};

export {
  MenderTooltip,
  MenderTooltipClickable,
  OnboardingTooltip,
  mendertooltip_default,
  HelpTooltip
};
//# sourceMappingURL=chunk-YYRZB2UY.js.map